### This display all variables

(see src/hatch_ci/tools.py:get_data)

- **ctx.version**  {ctx.version}
- **ctx.current**  {ctx.current}
- **ctx.ref**      {ctx.ref}
- **ctx.branch**   {ctx.branch}
- **ctx.sha**      {ctx.sha}
- **ctx.build**    {ctx.build}
- **ctx.runid**    {ctx.runid}
- **ctx.workflow** {ctx.workflow}